Changelog
=========

1.2.0
-----

* Do not use deprecated AttributeExtension, use Attribute Events instead.

1.1.0
-----

* Use an OR operator for LIKE_OPS to find matches in all language columns.

1.0.1
-----

* Fix `get_text_from_dict` raising an exception when no language can be detected.

1.0.0
-----

* Initial public release
